==> jc-1.4.0.tar.gz: java/util/VMTimeZone.h <==
// final class java.util.VMTimeZone

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class cfd4d78238bc2274 java_util_VMTimeZone

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_VMTimeZone_H_
#define _JC_java_util_VMTimeZone_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_TimeZone$object;

// Typedefs
typedef struct _jc_java_util_VMTimeZone$sub_refs	_jc_java_util_VMTimeZone$sub_refs;
typedef struct _jc_java_util_VMTimeZone$sub_nonrefs	_jc_java_util_VMTimeZone$sub_nonrefs;
typedef struct _jc_java_util_VMTimeZone$refs	_jc_java_util_VMTimeZone$refs;
typedef struct _jc_java_util_VMTimeZone$nonrefs	_jc_java_util_VMTimeZone$nonrefs;
typedef struct _jc_java_util_VMTimeZone$object	_jc_java_util_VMTimeZone$object;

typedef const struct _jc_java_util_VMTimeZone$vmethods	_jc_java_util_VMTimeZone$vmethods;
typedef const struct _jc_java_util_VMTimeZone$vtable	_jc_java_util_VMTimeZone$vtable;
typedef const struct _jc_java_util_VMTimeZone$vtype	_jc_java_util_VMTimeZone$vtype;

// Constructors
extern void _jc_java_util_VMTimeZone$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_VMTimeZone$object *);

// Static methods
extern void _jc_java_util_VMTimeZone$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_util_TimeZone$object *_jc_java_util_VMTimeZone$method$getDefaultTimeZoneId$eabca08b068aec3c(_jc_env *);
extern struct _jc_java_lang_String$object *_jc_java_util_VMTimeZone$method$getSystemTimeZoneId$39fc03a7eee50b9a(_jc_env *);
extern struct _jc_java_lang_String$object *_jc_java_util_VMTimeZone$method$readTimeZoneFile$b719e13596c44c9d(_jc_env *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_String$object *_jc_java_util_VMTimeZone$method$readtzFile$ee42bf5aac739e9e(_jc_env *, struct _jc_java_lang_String$object *);
extern void _jc_java_util_VMTimeZone$method$skipFully$143f8fd96ae0e06e(_jc_env *, struct _jc_java_io_InputStream$object *, jlong);

// Virtual methods structure
struct _jc_java_util_VMTimeZone$vmethods {
};

// Vtable
struct _jc_java_util_VMTimeZone$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_VMTimeZone$vmethods	java_util_VMTimeZone;
};

// Vtype
struct _jc_java_util_VMTimeZone$vtype {
	_jc_type			type;
	_jc_java_util_VMTimeZone$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_VMTimeZone$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_VMTimeZone$refs {
    _jc_java_util_VMTimeZone$sub_refs	java_util_VMTimeZone;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_VMTimeZone$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_VMTimeZone$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_VMTimeZone$sub_nonrefs	java_util_VMTimeZone;
};

// Object instance structure
struct _jc_java_util_VMTimeZone$object {
	_jc_java_util_VMTimeZone$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_VMTimeZone$vtype	*vtype;
	_jc_java_util_VMTimeZone$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_VMTimeZone$vtype _jc_java_util_VMTimeZone$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_VMTimeZone, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_VMTimeZone$class_object;

#endif	/* _JC_java_util_VMTimeZone_H_ */

==> jc-1.4.6.tar.gz: java/util/VMTimeZone.h <==
// final class java.util.VMTimeZone

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class cfd4d78238bc2274 java_util_VMTimeZone

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_VMTimeZone_H_
#define _JC_java_util_VMTimeZone_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_TimeZone$object;

// Typedefs
typedef struct _jc_java_util_VMTimeZone$sub_refs	_jc_java_util_VMTimeZone$sub_refs;
typedef struct _jc_java_util_VMTimeZone$sub_nonrefs	_jc_java_util_VMTimeZone$sub_nonrefs;
typedef struct _jc_java_util_VMTimeZone$refs	_jc_java_util_VMTimeZone$refs;
typedef struct _jc_java_util_VMTimeZone$nonrefs	_jc_java_util_VMTimeZone$nonrefs;
typedef struct _jc_java_util_VMTimeZone$object	_jc_java_util_VMTimeZone$object;

typedef const struct _jc_java_util_VMTimeZone$vmethods	_jc_java_util_VMTimeZone$vmethods;
typedef const struct _jc_java_util_VMTimeZone$vtable	_jc_java_util_VMTimeZone$vtable;
typedef const struct _jc_java_util_VMTimeZone$vtype	_jc_java_util_VMTimeZone$vtype;

// Constructors
extern void _jc_java_util_VMTimeZone$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_VMTimeZone$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_java_util_VMTimeZone$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_util_TimeZone$object *_jc_java_util_VMTimeZone$method$getDefaultTimeZoneId$eabca08b068aec3c(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_util_VMTimeZone$method$getSystemTimeZoneId$39fc03a7eee50b9a(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_util_VMTimeZone$method$readTimeZoneFile$b719e13596c44c9d(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_util_VMTimeZone$method$readtzFile$ee42bf5aac739e9e(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_VMTimeZone$method$skipFully$143f8fd96ae0e06e(_jc_env *, struct _jc_java_io_InputStream$object *, jlong) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_util_VMTimeZone$vmethods {
};

// Vtable
struct _jc_java_util_VMTimeZone$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_VMTimeZone$vmethods	java_util_VMTimeZone;
};

// Vtype
struct _jc_java_util_VMTimeZone$vtype {
	_jc_type			type;
	_jc_java_util_VMTimeZone$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_VMTimeZone$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_VMTimeZone$refs {
    _jc_java_util_VMTimeZone$sub_refs	java_util_VMTimeZone;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_VMTimeZone$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_VMTimeZone$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_VMTimeZone$sub_nonrefs	java_util_VMTimeZone;
};

// Object instance structure
struct _jc_java_util_VMTimeZone$object {
	_jc_java_util_VMTimeZone$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_VMTimeZone$vtype	*vtype;
	_jc_java_util_VMTimeZone$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_VMTimeZone$vtype _jc_java_util_VMTimeZone$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_VMTimeZone, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_VMTimeZone$class_object;

#endif	/* _JC_java_util_VMTimeZone_H_ */
